searchData={"items":[{"type":"module","title":"NOAA.Observations","doc":"Fetches weather observations for a US state/territory code.","ref":"NOAA.Observations.html"},{"type":"function","title":"NOAA.Observations.fetch/2","doc":"Fetches weather observations for a `state_code`.","ref":"NOAA.Observations.html#fetch/2"},{"type":"function","title":"Parameters - NOAA.Observations.fetch/2","doc":"- `state_code` - US state/territory code","ref":"NOAA.Observations.html#fetch/2-parameters"},{"type":"function","title":"Examples - NOAA.Observations.fetch/2","doc":"iex> alias NOAA.Observations\n    iex> alias NOAA.Observations.TemplatesAgent\n    iex> :ok = TemplatesAgent.refresh()\n    iex> %{ok: observations} = Observations.fetch(\"VT\")\n    iex> Enum.all?(observations, &is_map/1) and length(observations) > 0\n    true\n\n    iex> alias NOAA.Observations\n    iex> alias NOAA.Observations.TemplatesAgent\n    iex> template =\n    ...>   \"http://forecast.weather.gov/xml/current_obs\" <>\n    ...>     \"/seek.php?state=<%=state_code%>&Find=Find\"\n    iex> TemplatesAgent.update_state_template(template)\n    iex> {:error,\n    ...>  %{\n    ...>    error_code: 301,\n    ...>    error_text: \"Moved Permanently\",\n    ...>    state_url: url\n    ...>  }} = Observations.fetch(\"VT\")\n    iex> url\n    \"http://forecast.weather.gov/xml/current_obs/seek.php?state=VT&Find=Find\"\n\n    iex> alias NOAA.Observations\n    iex> alias NOAA.Observations.TemplatesAgent\n    iex> template =\n    ...>   \"https://www.weather.gov/xml/current_obs\" <>\n    ...>     \"/seek.php?state=<%=state_code%>&Find=Find\"\n    iex> TemplatesAgent.update_state_template(template)\n    iex> {:error,\n    ...>  %{\n    ...>    error_code: 302,\n    ...>    error_text: \"Found (Moved Temporarily)\",\n    ...>    state_url: url\n    ...>  }} = Observations.fetch(\"VT\")\n    ...> url\n    \"https://www.weather.gov/xml/current_obs/seek.php?state=VT&Find=Find\"\n\n    iex> alias NOAA.Observations\n    iex> alias NOAA.Observations.TemplatesAgent\n    iex> template =\n    ...>   \"https://forecast.weather.gov/xml/past_obs\" <>\n    ...>     \"/seek.php?state=<%=state_code%>&Find=Find\"\n    iex> TemplatesAgent.update_state_template(template)\n    iex> {:error,\n    ...>  %{error_code: 404, error_text: \"Not Found\", state_url: url}} =\n    ...>   Observations.fetch(\"VT\")\n    iex> url\n    \"https://forecast.weather.gov/xml/past_obs/seek.php?state=VT&Find=Find\"\n\n    iex> alias NOAA.Observations\n    iex> alias NOAA.Observations.TemplatesAgent\n    iex> template =\n    ...>   \"htp://forecast.weather.gov/xml/current_obs\" <>\n    ...>     \"/seek.php?state=<%=state_code%>&Find=Find\"\n    iex> TemplatesAgent.update_state_template(template)\n    iex> {:error,\n    ...>  %{\n    ...>    error_code: :nxdomain,\n    ...>    error_text: \"Non-Existent Domain\",\n    ...>    state_url: url\n    ...>  }} = Observations.fetch(\"VT\")\n    iex> url\n    \"htp://forecast.weather.gov/xml/current_obs/seek.php?state=VT&Find=Find\"\n\n    iex> alias NOAA.Observations\n    iex> alias NOAA.Observations.TemplatesAgent\n    iex> template = \"http://localhost:65535\"\n    iex> TemplatesAgent.update_state_template(template)\n    iex> {:error,\n    ...>  %{\n    ...>    error_code: :econnrefused,\n    ...>    error_text: \"Connection Refused By Server\",\n    ...>    state_url: url\n    ...>  }} = Observations.fetch(\"VT\")\n    iex> url\n    \"http://localhost:65535\"","ref":"NOAA.Observations.html#fetch/2-examples"},{"type":"module","title":"NOAA.Observations.CLI","doc":"Parses the command line and prints a table of weather observations\nfrom the NOAA Weather Service.\n\n##### Exercise in the book [Programming Elixir](https://pragprog.com/book/elixir16/programming-elixir-1-6) by Dave Thomas.","ref":"NOAA.Observations.CLI.html"},{"type":"function","title":"NOAA.Observations.CLI.main/1","doc":"Parses the command line and prints a table of weather observations\nfrom the NOAA Weather Service.\n\n`argv` can be \"-h\" or \"--help\", which prints info on the command's\nusage and syntax. Otherwise it is a US state/territory code\n(case-insensitive) and optionally the number of observations\nto format (the first _n_ ones).\nTo format the last _n_ observations, specify switch `--last`.\n\nTo ring the bell, specify switch `--bell`.\nTo choose a table style, specify switch `--table-style`.","ref":"NOAA.Observations.CLI.html#main/1"},{"type":"function","title":"Parameters - NOAA.Observations.CLI.main/1","doc":"- `argv` - command line arguments (list)","ref":"NOAA.Observations.CLI.html#main/1-parameters"},{"type":"function","title":"Switches - NOAA.Observations.CLI.main/1","doc":"- `-h` or `--help`        - for help\n  - `-b` or `--bell`        - to ring the bell\n  - `-l` or `--last`        - to format the last _n_ observations\n  - `-t` or `--table-style` - to choose a table style","ref":"NOAA.Observations.CLI.html#main/1-switches"},{"type":"function","title":"Table styles - NOAA.Observations.CLI.main/1","doc":"- `bare`                  - no colors\n  - `barish`                - like bare but colored\n  - `cyan`                  - cyan background\n  - `cyan-alt`              - cyan header, alternating row colors\n  - `cyan-border`           - light cyan border\n  - `cyan-mult`             - cyan header, 3 repeating row colors\n  - `dark`                  - dark colors\n  - `dark-alt`              - dark colors, alternating row colors\n  - `dark-mult`             - dark colors, 3 repeating row colors\n  - `dashed`                - no colors\n  - `dotted`                - slightly colored\n  - `dotted-alt`            - slightly colored, alternating row colors\n  - `dotted-mult`           - slightly colored, 3 repeating row colors\n  - `game`                  - game board\n  - `green`                 - green background\n  - `green-alt`             - green header, alternating row colors\n  - `green-border`          - light green border\n  - `green-border-padded`   - light green border with extra padding\n  - `green-border-unpadded` - light green border without padding\n  - `green-mult`            - green header, 3 repeating row colors\n  - `green-padded`          - like green but with extra padding\n  - `green-unpadded`        - like green but without padding\n  - `light`                 - light colors\n  - `light-alt`             - light colors, alternating row colors\n  - `light-mult`            - light colors, 3 repeating row colors\n  - `medium`                - medium colors\n  - `medium-alt`            - medium colors, alternating row colors\n  - `medium-mult`           - medium colors, 3 repeating row colors\n  - `mixed`                 - fillers revealed\n  - `plain`                 - slightly colored\n  - `pretty`                - multicolored\n  - `pretty-alt`            - multicolored, alternating row colors\n  - `pretty-mult`           - multicolored, 3 repeating row colors\n  - `test`                  - no colors\n  - `yellow`                - light yellow background\n  - `yellow-border`         - light yellow border","ref":"NOAA.Observations.CLI.html#main/1-table-styles"},{"type":"module","title":"NOAA.Observations.Help","doc":"Prints info on the escript command's usage and syntax.","ref":"NOAA.Observations.Help.html"},{"type":"function","title":"NOAA.Observations.Help.show_help/0","doc":"Prints info on the escript command's usage and syntax.","ref":"NOAA.Observations.Help.html#show_help/0"},{"type":"module","title":"NOAA.Observations.Log","doc":"","ref":"NOAA.Observations.Log.html"},{"type":"function","title":"NOAA.Observations.Log.error/2","doc":"","ref":"NOAA.Observations.Log.html#error/2"},{"type":"function","title":"NOAA.Observations.Log.info/2","doc":"","ref":"NOAA.Observations.Log.html#info/2"},{"type":"module","title":"NOAA.Observations.Message","doc":"","ref":"NOAA.Observations.Message.html"},{"type":"function","title":"NOAA.Observations.Message.error/1","doc":"","ref":"NOAA.Observations.Message.html#error/1"},{"type":"function","title":"NOAA.Observations.Message.stations_not_fetched/1","doc":"","ref":"NOAA.Observations.Message.html#stations_not_fetched/1"},{"type":"function","title":"NOAA.Observations.Message.status/1","doc":"","ref":"NOAA.Observations.Message.html#status/1"},{"type":"function","title":"NOAA.Observations.Message.timeout/2","doc":"","ref":"NOAA.Observations.Message.html#timeout/2"},{"type":"function","title":"NOAA.Observations.Message.writing_table/2","doc":"","ref":"NOAA.Observations.Message.html#writing_table/2"},{"type":"module","title":"NOAA.Observations.RetriesAgent","doc":"An agent process loading the maximum number of timeout retries.","ref":"NOAA.Observations.RetriesAgent.html"},{"type":"function","title":"NOAA.Observations.RetriesAgent.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"NOAA.Observations.RetriesAgent.html#child_spec/1"},{"type":"function","title":"NOAA.Observations.RetriesAgent.get_and_decrement/0","doc":"Gets and decrements the number of timeout retries in the retries agent.","ref":"NOAA.Observations.RetriesAgent.html#get_and_decrement/0"},{"type":"function","title":"Examples - NOAA.Observations.RetriesAgent.get_and_decrement/0","doc":"iex> alias NOAA.Observations.RetriesAgent\n    iex> RetriesAgent.refresh()\n    iex> bef_retries = RetriesAgent.get_and_decrement()\n    iex> aft_retries = Agent.get(& &1)\n    iex> aft_retries = bef_retries - 1\n    true","ref":"NOAA.Observations.RetriesAgent.html#get_and_decrement/0-examples"},{"type":"function","title":"NOAA.Observations.RetriesAgent.refresh/0","doc":"Refreshes the agent state.","ref":"NOAA.Observations.RetriesAgent.html#refresh/0"},{"type":"function","title":"NOAA.Observations.RetriesAgent.start_link/1","doc":"Spawns an agent process that loads the maximum number of timeout retries.","ref":"NOAA.Observations.RetriesAgent.html#start_link/1"},{"type":"function","title":"Examples - NOAA.Observations.RetriesAgent.start_link/1","doc":"iex> alias NOAA.Observations.RetriesAgent\n    iex> {:error, {:already_started, agent}} = RetriesAgent.start_link(:ok)\n    iex> is_pid(agent) and agent == Process.whereis(RetriesAgent)\n    true","ref":"NOAA.Observations.RetriesAgent.html#start_link/1-examples"},{"type":"module","title":"NOAA.Observations.State","doc":"Fetches the stations for a US state/territory code.","ref":"NOAA.Observations.State.html"},{"type":"type","title":"NOAA.Observations.State.code/0","doc":"US state/territory code","ref":"NOAA.Observations.State.html#t:code/0"},{"type":"type","title":"NOAA.Observations.State.error/0","doc":"Erroneous state","ref":"NOAA.Observations.State.html#t:error/0"},{"type":"function","title":"NOAA.Observations.State.stations/1","doc":"Fetches the stations for a `state_code`.\n\nReturns a tuple of either `{:ok, [station]}` or `{:error, error_code, text}`.","ref":"NOAA.Observations.State.html#stations/1"},{"type":"function","title":"Parameters - NOAA.Observations.State.stations/1","doc":"- `state_code` - US state/territory code","ref":"NOAA.Observations.State.html#stations/1-parameters"},{"type":"function","title":"Examples - NOAA.Observations.State.stations/1","doc":"iex> alias NOAA.Observations.{State, TemplatesAgent}\n    iex> :ok = TemplatesAgent.refresh()\n    iex> {:ok, stations} = State.stations(\"VT\")\n    iex> %{\"KFSO\" => name} = Map.new(stations)\n    iex> name\n    \"Franklin County State Airport\"\n\n    iex> alias NOAA.Observations.{State, TemplatesAgent}\n    iex> template =\n    ...>   \"http://forecast.weather.gov/xml/current_obs\" <>\n    ...>     \"/seek.php?state=<%=state_code%>&Find=Find\"\n    iex> TemplatesAgent.update_state_template(template)\n    iex> State.stations(\"VT\")\n    {:error, 301, \"Moved Permanently\"}\n\n    iex> alias NOAA.Observations.{State, TemplatesAgent}\n    iex> template =\n    ...>   \"https://www.weather.gov/xml/current_obs\" <>\n    ...>     \"/seek.php?state=<%=state_code%>&Find=Find\"\n    iex> TemplatesAgent.update_state_template(template)\n    iex> State.stations(\"VT\")\n    {:error, 302, \"Found (Moved Temporarily)\"}\n\n    iex> alias NOAA.Observations.{State, TemplatesAgent}\n    iex> template =\n    ...>   \"https://forecast.weather.gov/xml/past_obs\" <>\n    ...>     \"/seek.php?state=<%=state_code%>&Find=Find\"\n    iex> TemplatesAgent.update_state_template(template)\n    iex> State.stations(\"VT\")\n    {:error, 404, \"Not Found\"}\n\n    iex> alias NOAA.Observations.{State, TemplatesAgent}\n    iex> template =\n    ...>   \"htp://forecast.weather.gov/xml/current_obs\" <>\n    ...>     \"/seek.php?state=<%=state_code%>&Find=Find\"\n    iex> TemplatesAgent.update_state_template(template)\n    iex> State.stations(\"VT\")\n    {:error, :nxdomain, \"Non-Existent Domain\"}\n\n    iex> alias NOAA.Observations.{State, TemplatesAgent}\n    iex> template = \"http://localhost:65535\"\n    iex> TemplatesAgent.update_state_template(template)\n    iex> State.stations(\"VT\")\n    {:error, :econnrefused, \"Connection Refused By Server\"}\n\n    iex> alias NOAA.Observations.{State, TemplatesAgent}\n    iex> template = \"http://localhost:0\"\n    iex> TemplatesAgent.update_state_template(template)\n    iex> State.stations(\"VT\")\n    {:error, :eaddrnotavail, \"Address Not Available\"}","ref":"NOAA.Observations.State.html#stations/1-examples"},{"type":"module","title":"NOAA.Observations.Station","doc":"Fetches the latest observation for a given NOAA station.","ref":"NOAA.Observations.Station.html"},{"type":"type","title":"NOAA.Observations.Station.error/0","doc":"Erroneous station","ref":"NOAA.Observations.Station.html#t:error/0"},{"type":"type","title":"NOAA.Observations.Station.id/0","doc":"Station ID","ref":"NOAA.Observations.Station.html#t:id/0"},{"type":"type","title":"NOAA.Observations.Station.name/0","doc":"Station name","ref":"NOAA.Observations.Station.html#t:name/0"},{"type":"type","title":"NOAA.Observations.Station.observation/0","doc":"NOAA weather observation","ref":"NOAA.Observations.Station.html#t:observation/0"},{"type":"function","title":"NOAA.Observations.Station.observation/2","doc":"Fetches the latest observation for a given NOAA `station`.\n\nReturns either tuple `{:ok, observation}` or tuple `{:error, error}`.","ref":"NOAA.Observations.Station.html#observation/2"},{"type":"function","title":"Parameters - NOAA.Observations.Station.observation/2","doc":"- `{station_id, station_name}` - NOAA station\n  - `state_code`                 - US state/territory code","ref":"NOAA.Observations.Station.html#observation/2-parameters"},{"type":"function","title":"Examples - NOAA.Observations.Station.observation/2","doc":"iex> alias NOAA.Observations.{Station, TemplatesAgent}\n    iex> :ok = TemplatesAgent.refresh()\n    iex> {:ok, observation} =\n    ...>   Station.observation({\"KFSO\", \"KFSO name\"}, \"VT\")\n    iex> is_map(observation) and is_binary(observation[\"wind_mph\"])\n    true\n\n    iex> alias NOAA.Observations.{Station, TemplatesAgent}\n    iex> template =\n    ...>   \"htp://forecast.weather.gov/xml/current_obs\" <>\n    ...>     \"/display.php?stid=<%=station_id%>\"\n    iex> TemplatesAgent.update_station_template(template)\n    iex> {:error, %{error_text: text, error_code: code, station_id: id}} =\n    ...>   Station.observation({\"KFSO\", \"KFSO name\"}, \"VT\")\n    iex> {text, code, id}\n    {\"Non-Existent Domain\", :nxdomain, \"KFSO\"}\n\n    iex> alias NOAA.Observations.{Station, TemplatesAgent}\n    iex> template =\n    ...>   \"https://forecast.weather.gov/xml/past_obs\" <>\n    ...>     \"/display.php?stid=<%=station_id%>\"\n    iex> TemplatesAgent.update_station_template(template)\n    iex> {:error, %{error_text: text, error_code: code, station_id: id}} =\n    ...>   Station.observation({\"KFSO\", \"KFSO name\"}, \"VT\")\n    iex> {text, code, id}\n    {\"Not Found\", 404, \"KFSO\"}","ref":"NOAA.Observations.Station.html#observation/2-examples"},{"type":"type","title":"NOAA.Observations.Station.t/0","doc":"NOAA station","ref":"NOAA.Observations.Station.html#t:t/0"},{"type":"module","title":"NOAA.Observations.TemplatesAgent","doc":"An agent process loading the state and station URL templates.","ref":"NOAA.Observations.TemplatesAgent.html"},{"type":"function","title":"NOAA.Observations.TemplatesAgent.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"NOAA.Observations.TemplatesAgent.html#child_spec/1"},{"type":"function","title":"NOAA.Observations.TemplatesAgent.refresh/0","doc":"Refreshes the agent state.","ref":"NOAA.Observations.TemplatesAgent.html#refresh/0"},{"type":"function","title":"NOAA.Observations.TemplatesAgent.start_link/1","doc":"Spawns an agent process that loads the state and station URL templates.","ref":"NOAA.Observations.TemplatesAgent.html#start_link/1"},{"type":"function","title":"Examples - NOAA.Observations.TemplatesAgent.start_link/1","doc":"iex> alias NOAA.Observations.TemplatesAgent\n    iex> {:error, {:already_started, agent}} = TemplatesAgent.start_link(:ok)\n    iex> is_pid(agent) and agent == Process.whereis(TemplatesAgent)\n    true","ref":"NOAA.Observations.TemplatesAgent.html#start_link/1-examples"},{"type":"function","title":"NOAA.Observations.TemplatesAgent.state_url/1","doc":"Returns a state URL based on `binding` and the state of the templates agent.","ref":"NOAA.Observations.TemplatesAgent.html#state_url/1"},{"type":"function","title":"Examples - NOAA.Observations.TemplatesAgent.state_url/1","doc":"iex> alias NOAA.Observations.TemplatesAgent\n    iex> TemplatesAgent.refresh()\n    iex> TemplatesAgent.state_url(state_code: \"VT\")\n    \"https://forecast.weather.gov/xml/current_obs/seek.php?state=VT&Find=Find\"\n\n    iex> alias NOAA.Observations.TemplatesAgent\n    iex> template = \"http://noaa.gov/seek.php?state=<%=state_abbr%>&Find=Find\"\n    iex> TemplatesAgent.update_state_template(template)\n    iex> TemplatesAgent.state_url(state_abbr: \"NY\")\n    \"http://noaa.gov/seek.php?state=NY&Find=Find\"","ref":"NOAA.Observations.TemplatesAgent.html#state_url/1-examples"},{"type":"function","title":"NOAA.Observations.TemplatesAgent.station_url/1","doc":"Returns a station URL based on `binding` and the state of the templates agent.","ref":"NOAA.Observations.TemplatesAgent.html#station_url/1"},{"type":"function","title":"Examples - NOAA.Observations.TemplatesAgent.station_url/1","doc":"iex> alias NOAA.Observations.TemplatesAgent\n    iex> TemplatesAgent.refresh()\n    iex> TemplatesAgent.station_url(station_id: \"KFSO\")\n    \"https://forecast.weather.gov/xml/current_obs/display.php?stid=KFSO\"\n\n    iex> alias NOAA.Observations.TemplatesAgent\n    iex> template = \"http://noaa.gov/display.php?stid=<%=stn_id%>\"\n    iex> TemplatesAgent.update_station_template(template)\n    iex> TemplatesAgent.station_url(stn_id: \"KBTV\")\n    \"http://noaa.gov/display.php?stid=KBTV\"","ref":"NOAA.Observations.TemplatesAgent.html#station_url/1-examples"},{"type":"type","title":"NOAA.Observations.TemplatesAgent.template/0","doc":"URL template","ref":"NOAA.Observations.TemplatesAgent.html#t:template/0"},{"type":"function","title":"NOAA.Observations.TemplatesAgent.update_state_template/1","doc":"Updates the state URL template in the templates agent.","ref":"NOAA.Observations.TemplatesAgent.html#update_state_template/1"},{"type":"function","title":"Examples - NOAA.Observations.TemplatesAgent.update_state_template/1","doc":"iex> alias NOAA.Observations.TemplatesAgent\n    iex> template = \"http://noaa.gov/seek.php?state=<%=state_code%>&Find=Find\"\n    iex> TemplatesAgent.update_state_template(template)\n    iex> Agent.get(TemplatesAgent, & &1.state) == template\n    true","ref":"NOAA.Observations.TemplatesAgent.html#update_state_template/1-examples"},{"type":"function","title":"NOAA.Observations.TemplatesAgent.update_station_template/1","doc":"Updates the station URL template in the templates agent.","ref":"NOAA.Observations.TemplatesAgent.html#update_station_template/1"},{"type":"function","title":"Examples - NOAA.Observations.TemplatesAgent.update_station_template/1","doc":"iex> alias NOAA.Observations.TemplatesAgent\n    iex> template = \"http://noaa.gov/display.php?stid=<%=station_id%>\"\n    iex> TemplatesAgent.update_station_template(template)\n    iex> Agent.get(TemplatesAgent, & &1.station) == template\n    true","ref":"NOAA.Observations.TemplatesAgent.html#update_station_template/1-examples"},{"type":"type","title":"NOAA.Observations.TemplatesAgent.url/0","doc":"URL","ref":"NOAA.Observations.TemplatesAgent.html#t:url/0"},{"type":"module","title":"NOAA.Observations.TopSup","doc":"","ref":"NOAA.Observations.TopSup.html"},{"type":"function","title":"NOAA.Observations.TopSup.start/2","doc":"Callback implementation for  Application.start/2 .","ref":"NOAA.Observations.TopSup.html#start/2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}